@@ -14,6 +14,53 @@
 
 from __future__ import absolute_import
 
+__all__ = ['apt_get',
+           'arm_allinea_studio',
+           'boost',
+           'catalyst',
+           'cgns',
+           'charm',
+           'cmake',
+           'conda',
+           'fftw',
+           'gdrcopy',
+           'generic_autotools',
+           'generic_build',
+           'generic_cmake',
+           'gnu',
+           'hdf5',
+           'hpcx',
+           'intel_mpi',
+           'intel_psxe',
+           'intel_psxe_runtime',
+           'julia',
+           'knem',
+           'kokkos',
+           'libsim',
+           'llvm',
+           'mkl',
+           'mlnx_ofed',
+           'mpich',
+           'multi_ofed',
+           'mvapich2_gdr',
+           'mvapich2',
+           'netcdf',
+           'ofed',
+           'openblas',
+           'openmpi',
+           'packages',
+           'pgi',
+           'pip',
+           'pmix',
+           'pnetcdf',
+           'python',
+           'scif',
+           'sensei',
+           'slurm_pmi2',
+           'ucx',
+           'xpmem',
+           'yum']
+
 from hpccm.building_blocks.apt_get import apt_get
 from hpccm.building_blocks.arm_allinea_studio import arm_allinea_studio
 from hpccm.building_blocks.boost import boost
