@@ -21,7 +21,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-import logging # pylint: disable=unused-import
 import re
 import posixpath
 
@@ -79,7 +78,7 @@ class boost(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
     SourceForge repository should be used.  The default is False.
 
     version: The version of Boost source to download.  The default
-    value is `1.70.0`.
+    value is `1.72.0`.
 
     # Examples
 
@@ -106,7 +105,7 @@ class boost(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
         self.__prefix = kwargs.get('prefix', '/usr/local/boost')
         self.__python = kwargs.get('python', False)
         self.__sourceforge = kwargs.get('sourceforge', False)
-        self.__version = kwargs.get('version', '1.70.0')
+        self.__version = kwargs.get('version', '1.72.0')
 
         self.__commands = [] # Filled in by __setup()
         self.__wd = '/var/tmp' # working directory
@@ -171,8 +170,7 @@ class boost(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
             self.__bootstrap_opts.append('--without-libraries=python')
 
         # Download source from web
-        self.__commands.append(self.download_step(url=url,
-                                                  directory=self.__wd))
+        self.__commands.append(self.download_step(url=url, directory=self.__wd))
         self.__commands.append(self.untar_step(
             tarball=posixpath.join(self.__wd, tarball), directory=self.__wd))
 
