@@ -21,7 +21,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-import logging # pylint: disable=unused-import
 import posixpath
 
 import hpccm.config
@@ -202,9 +201,7 @@ class libsim(bb_base, hpccm.templates.envvars, hpccm.templates.ldconfig,
         url = self.__url.format(self.__version, buildscript)
 
         # Download source from web
-        self.__commands.append(self.download_step(
-            url=url,
-            directory=self.__wd))
+        self.__commands.append(self.download_step(url=url, directory=self.__wd))
 
         # Set options
         env = []
