@@ -21,7 +21,6 @@ from __future__ import unicode_literals
 from __future__ import print_function
 
 from distutils.version import StrictVersion
-import logging # pylint: disable=unused-import
 import posixpath
 
 import hpccm.config
@@ -77,7 +76,7 @@ class mlnx_ofed(bb_base, hpccm.templates.rm, hpccm.templates.tar,
     via the package manager to the standard system locations.
 
     version: The version of Mellanox OFED to download.  The default
-    value is `4.6-1.0.1.1`.
+    value is `4.7-3.2.9.0`.
 
     # Examples
 
@@ -102,7 +101,7 @@ class mlnx_ofed(bb_base, hpccm.templates.rm, hpccm.templates.tar,
         self.__packages = kwargs.get('packages', [])
         self.__prefix = kwargs.get('prefix', None)
         self.__symlink = kwargs.get('symlink', False)
-        self.__version = kwargs.get('version', '4.6-1.0.1.1')
+        self.__version = kwargs.get('version', '4.7-3.2.9.0')
 
         self.__commands = []
         self.__wd = '/var/tmp'
@@ -222,8 +221,7 @@ class mlnx_ofed(bb_base, hpccm.templates.rm, hpccm.templates.tar,
                                              tarball)
 
         # Download and unpackage
-        self.__commands.append(self.download_step(url=url,
-                                                  directory=self.__wd))
+        self.__commands.append(self.download_step(url=url, directory=self.__wd))
         self.__commands.append(self.untar_step(
             tarball=posixpath.join(self.__wd, tarball), directory=self.__wd))
 
