@@ -21,7 +21,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-import logging # pylint: disable=unused-import
 import posixpath
 import re
 from copy import copy as _copy
@@ -81,6 +80,16 @@ class mvapich2(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
     defined, the source in the local build context will be used rather
     than downloading the source from the web.
 
+    disable_FEATURE: Flags to control disabling features when
+    configuring.  For instance, `disable_foo=True` maps to
+    `--disable-foo`.  Underscores in the parameter name are converted
+    to dashes.
+
+    enable_FEATURE[=ARG]: Flags to control enabling features when
+    configuring.  For instance, `enable_foo=True` maps to
+    `--enable-foo` and `enable_foo='yes'` maps to `--enable-foo=yes`.
+    Underscores in the parameter name are converted to dashes.
+
     environment: Boolean flag to specify whether the environment
     (`LD_LIBRARY_PATH` and `PATH`) should be modified to include
     MVAPICH2. The default is True.
@@ -109,7 +118,18 @@ class mvapich2(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
     default is empty.
 
     version: The version of MVAPICH2 source to download.  This value
-    is ignored if `directory` is set.  The default value is `2.3.1`.
+    is ignored if `directory` is set.  The default value is `2.3.3`.
+
+    with_PACKAGE[=ARG]: Flags to control optional packages when
+    configuring.  For instance, `with_foo=True` maps to `--with-foo`
+    and `with_foo='/usr/local/foo'` maps to
+    `--with-foo=/usr/local/foo`.  Underscores in the parameter name
+    are converted to dashes.
+
+    without_PACKAGE: Flags to control optional packages when
+    configuring.  For instance `without_foo=True` maps to
+    `--without-foo`.  Underscores in the parameter name are converted
+    to dashes.
 
     # Examples
 
@@ -150,7 +170,7 @@ class mvapich2(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         # MVAPICH2 does not accept F90
         self.toolchain_control = {'CC': True, 'CXX': True, 'F77': True,
                                   'F90': False, 'FC': True}
-        self.version = kwargs.get('version', '2.3.1')
+        self.version = kwargs.get('version', '2.3.3')
 
         self.__commands = []              # Filled in by __setup()
 
@@ -277,7 +297,7 @@ class mvapich2(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         else:
             # Download source from web
             self.__commands.append(self.download_step(url=url,
-                                                      directory=self.__wd))
+                                   directory=self.__wd))
             self.__commands.append(self.untar_step(
                 tarball=posixpath.join(self.__wd, tarball),
                 directory=self.__wd))
