@@ -22,7 +22,6 @@ from __future__ import unicode_literals
 from __future__ import print_function
 
 from distutils.version import LooseVersion
-import logging # pylint: disable=unused-import
 import posixpath
 
 import hpccm.config
@@ -58,6 +57,16 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
     configure_opts: List of options to pass to `configure`.  The
     default values are `--enable-shared`.
 
+    disable_FEATURE: Flags to control disabling features when
+    configuring.  For instance, `disable_foo=True` maps to
+    `--disable-foo`.  Underscores in the parameter name are converted
+    to dashes.
+
+    enable_FEATURE[=ARG]: Flags to control enabling features when
+    configuring.  For instance, `enable_foo=True` maps to
+    `--enable-foo` and `enable_foo='yes'` maps to `--enable-foo=yes`.
+    Underscores in the parameter name are converted to dashes.
+
     environment: Boolean flag to specify whether the environment
     (`LD_LIBRARY_PATH` and `PATH`) should be modified to include
     PnetCDF. The default is True.
@@ -79,7 +88,18 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
     e.g., `CC=mpicc`, `CXX=mpicxx`, etc.
 
     version: The version of PnetCDF source to download.  The default
-    value is `1.11.2`.
+    value is `1.12.1`.
+
+    with_PACKAGE[=ARG]: Flags to control optional packages when
+    configuring.  For instance, `with_foo=True` maps to `--with-foo`
+    and `with_foo='/usr/local/foo'` maps to
+    `--with-foo=/usr/local/foo`.  Underscores in the parameter name
+    are converted to dashes.
+
+    without_PACKAGE: Flags to control optional packages when
+    configuring.  For instance `without_foo=True` maps to
+    `--without-foo`.  Underscores in the parameter name are converted
+    to dashes.
 
     # Examples
 
@@ -111,7 +131,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
                                       toolchain(CC='mpicc', CXX='mpicxx',
                                                 F77='mpif77', F90='mpif90',
                                                 FC='mpifort'))
-        self.__version = kwargs.get('version', '1.11.2')
+        self.__version = kwargs.get('version', '1.12.1')
 
         self.__commands = [] # Filled in by __setup()
         self.__wd = '/var/tmp' # working directory
@@ -157,8 +177,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
         url = '{0}/{1}'.format(self.__baseurl, tarball)
 
         # Download source from web
-        self.__commands.append(self.download_step(url=url,
-                                                  directory=self.__wd))
+        self.__commands.append(self.download_step(url=url, directory=self.__wd))
         self.__commands.append(self.untar_step(
             tarball=posixpath.join(self.__wd, tarball), directory=self.__wd))
         self.__commands.append(self.configure_step(
