@@ -21,9 +21,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-import logging # pylint: disable=unused-import
 import posixpath
-import re
 
 import hpccm.templates.CMakeBuild
 import hpccm.templates.git
